Class: Parlo::Domain

Inherits:
ApiModelBase show all
Defined in:
lib/parlo-sdk/models/domain.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Domain

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/parlo-sdk/models/domain.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Parlo::Domain` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Parlo::Domain`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'verified_at')
    self.verified_at = attributes[:'verified_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'records')
    if (value = attributes[:'records']).is_a?(Array)
      self.records = value
    end
  else
    self.records = nil
  end

  if attributes.key?(:'auth')
    self.auth = attributes[:'auth']
  else
    self.auth = nil
  end
end

Instance Attribute Details

#authObject

Returns the value of attribute auth.



30
31
32
# File 'lib/parlo-sdk/models/domain.rb', line 30

def auth
  @auth
end

#created_atObject

Returns the value of attribute created_at.



26
27
28
# File 'lib/parlo-sdk/models/domain.rb', line 26

def created_at
  @created_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/parlo-sdk/models/domain.rb', line 18

def id
  @id
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/parlo-sdk/models/domain.rb', line 20

def name
  @name
end

#recordsObject

Returns the value of attribute records.



28
29
30
# File 'lib/parlo-sdk/models/domain.rb', line 28

def records
  @records
end

#statusObject

Returns the value of attribute status.



22
23
24
# File 'lib/parlo-sdk/models/domain.rb', line 22

def status
  @status
end

#verified_atObject

Returns the value of attribute verified_at.



24
25
26
# File 'lib/parlo-sdk/models/domain.rb', line 24

def verified_at
  @verified_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



68
69
70
# File 'lib/parlo-sdk/models/domain.rb', line 68

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



73
74
75
# File 'lib/parlo-sdk/models/domain.rb', line 73

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
# File 'lib/parlo-sdk/models/domain.rb', line 55

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'status' => :'status',
    :'verified_at' => :'verified_at',
    :'created_at' => :'created_at',
    :'records' => :'records',
    :'auth' => :'auth'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/parlo-sdk/models/domain.rb', line 281

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



97
98
99
100
101
# File 'lib/parlo-sdk/models/domain.rb', line 97

def self.openapi_all_of
  [
  :'DomainSummary'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/parlo-sdk/models/domain.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



78
79
80
81
82
83
84
85
86
87
88
# File 'lib/parlo-sdk/models/domain.rb', line 78

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'status' => :'String',
    :'verified_at' => :'Time',
    :'created_at' => :'Time',
    :'records' => :'Array<DnsRecord>',
    :'auth' => :'AuthHealth'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



254
255
256
257
258
259
260
261
262
263
264
# File 'lib/parlo-sdk/models/domain.rb', line 254

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      status == o.status &&
      verified_at == o.verified_at &&
      created_at == o.created_at &&
      records == o.records &&
      auth == o.auth
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


268
269
270
# File 'lib/parlo-sdk/models/domain.rb', line 268

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



274
275
276
# File 'lib/parlo-sdk/models/domain.rb', line 274

def hash
  [id, name, status, verified_at, created_at, records, auth].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/parlo-sdk/models/domain.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @records.nil?
    invalid_properties.push('invalid value for "records", records cannot be nil.')
  end

  if @auth.nil?
    invalid_properties.push('invalid value for "auth", auth cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



303
304
305
306
307
308
309
310
311
312
313
314
315
# File 'lib/parlo-sdk/models/domain.rb', line 303

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
195
196
197
198
199
200
# File 'lib/parlo-sdk/models/domain.rb', line 190

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["pending", "verified", "failed"])
  return false unless status_validator.valid?(@status)
  return false if @records.nil?
  return false if @auth.nil?
  true
end