Class: Parlo::EmailSummary

Inherits:
ApiModelBase show all
Defined in:
lib/parlo-sdk/models/email_summary.rb

Overview

One email as returned in a list. Parlo does not retain the body of a transactional message, so none is included here or anywhere in this API.

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ EmailSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/parlo-sdk/models/email_summary.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Parlo::EmailSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Parlo::EmailSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'to')
    if (value = attributes[:'to']).is_a?(Array)
      self.to = value
    end
  else
    self.to = nil
  end

  if attributes.key?(:'from')
    self.from = attributes[:'from']
  else
    self.from = nil
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  else
    self.subject = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'opened')
    self.opened = attributes[:'opened']
  else
    self.opened = nil
  end

  if attributes.key?(:'clicked')
    self.clicked = attributes[:'clicked']
  else
    self.clicked = nil
  end

  if attributes.key?(:'last_event_at')
    self.last_event_at = attributes[:'last_event_at']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#clickedObject

Returns the value of attribute clicked.



31
32
33
# File 'lib/parlo-sdk/models/email_summary.rb', line 31

def clicked
  @clicked
end

#created_atObject

Returns the value of attribute created_at.



35
36
37
# File 'lib/parlo-sdk/models/email_summary.rb', line 35

def created_at
  @created_at
end

#fromObject

Returns the value of attribute from.



23
24
25
# File 'lib/parlo-sdk/models/email_summary.rb', line 23

def from
  @from
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/parlo-sdk/models/email_summary.rb', line 19

def id
  @id
end

#last_event_atObject

Returns the value of attribute last_event_at.



33
34
35
# File 'lib/parlo-sdk/models/email_summary.rb', line 33

def last_event_at
  @last_event_at
end

#openedObject

Returns the value of attribute opened.



29
30
31
# File 'lib/parlo-sdk/models/email_summary.rb', line 29

def opened
  @opened
end

#statusObject

Returns the value of attribute status.



27
28
29
# File 'lib/parlo-sdk/models/email_summary.rb', line 27

def status
  @status
end

#subjectObject

Returns the value of attribute subject.



25
26
27
# File 'lib/parlo-sdk/models/email_summary.rb', line 25

def subject
  @subject
end

#toObject

Returns the value of attribute to.



21
22
23
# File 'lib/parlo-sdk/models/email_summary.rb', line 21

def to
  @to
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/parlo-sdk/models/email_summary.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/parlo-sdk/models/email_summary.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/parlo-sdk/models/email_summary.rb', line 60

def self.attribute_map
  {
    :'id' => :'id',
    :'to' => :'to',
    :'from' => :'from',
    :'subject' => :'subject',
    :'status' => :'status',
    :'opened' => :'opened',
    :'clicked' => :'clicked',
    :'last_event_at' => :'last_event_at',
    :'created_at' => :'created_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/parlo-sdk/models/email_summary.rb', line 329

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



100
101
102
103
104
105
# File 'lib/parlo-sdk/models/email_summary.rb', line 100

def self.openapi_nullable
  Set.new([
    :'last_event_at',
    :'created_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
# File 'lib/parlo-sdk/models/email_summary.rb', line 85

def self.openapi_types
  {
    :'id' => :'String',
    :'to' => :'Array<String>',
    :'from' => :'String',
    :'subject' => :'String',
    :'status' => :'String',
    :'opened' => :'Boolean',
    :'clicked' => :'Boolean',
    :'last_event_at' => :'Time',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/parlo-sdk/models/email_summary.rb', line 300

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      to == o.to &&
      from == o.from &&
      subject == o.subject &&
      status == o.status &&
      opened == o.opened &&
      clicked == o.clicked &&
      last_event_at == o.last_event_at &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


316
317
318
# File 'lib/parlo-sdk/models/email_summary.rb', line 316

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



322
323
324
# File 'lib/parlo-sdk/models/email_summary.rb', line 322

def hash
  [id, to, from, subject, status, opened, clicked, last_event_at, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/parlo-sdk/models/email_summary.rb', line 178

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @to.nil?
    invalid_properties.push('invalid value for "to", to cannot be nil.')
  end

  if @from.nil?
    invalid_properties.push('invalid value for "from", from cannot be nil.')
  end

  if @subject.nil?
    invalid_properties.push('invalid value for "subject", subject cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @opened.nil?
    invalid_properties.push('invalid value for "opened", opened cannot be nil.')
  end

  if @clicked.nil?
    invalid_properties.push('invalid value for "clicked", clicked cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/parlo-sdk/models/email_summary.rb', line 351

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/parlo-sdk/models/email_summary.rb', line 214

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @to.nil?
  return false if @from.nil?
  return false if @subject.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["queued", "sent", "delivered", "bounced", "complained", "failed"])
  return false unless status_validator.valid?(@status)
  return false if @opened.nil?
  return false if @clicked.nil?
  true
end