Class: Parlo::Email
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Parlo::Email
- Defined in:
- lib/parlo-sdk/models/email.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#clicked ⇒ Object
Returns the value of attribute clicked.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#error ⇒ Object
Why the send failed, as reported by the email provider.
-
#from ⇒ Object
Returns the value of attribute from.
-
#id ⇒ Object
Returns the value of attribute id.
-
#last_event_at ⇒ Object
Returns the value of attribute last_event_at.
-
#opened ⇒ Object
Returns the value of attribute opened.
-
#status ⇒ Object
Returns the value of attribute status.
-
#stream ⇒ Object
Returns the value of attribute stream.
-
#subject ⇒ Object
Returns the value of attribute subject.
-
#tags ⇒ Object
The tags supplied when the email was sent.
-
#to ⇒ Object
Returns the value of attribute to.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Email
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Email
Initializes the object
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/parlo-sdk/models/email.rb', line 128 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Parlo::Email` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Parlo::Email`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'to') if (value = attributes[:'to']).is_a?(Array) self.to = value end else self.to = nil end if attributes.key?(:'from') self.from = attributes[:'from'] else self.from = nil end if attributes.key?(:'subject') self.subject = attributes[:'subject'] else self.subject = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'opened') self.opened = attributes[:'opened'] else self.opened = nil end if attributes.key?(:'clicked') self.clicked = attributes[:'clicked'] else self.clicked = nil end if attributes.key?(:'last_event_at') self.last_event_at = attributes[:'last_event_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'stream') self.stream = attributes[:'stream'] else self.stream = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Hash) self. = value end else self. = nil end if attributes.key?(:'error') self.error = attributes[:'error'] else self.error = nil end end |
Instance Attribute Details
#clicked ⇒ Object
Returns the value of attribute clicked.
30 31 32 |
# File 'lib/parlo-sdk/models/email.rb', line 30 def clicked @clicked end |
#created_at ⇒ Object
Returns the value of attribute created_at.
34 35 36 |
# File 'lib/parlo-sdk/models/email.rb', line 34 def created_at @created_at end |
#error ⇒ Object
Why the send failed, as reported by the email provider. Null unless status is failed.
42 43 44 |
# File 'lib/parlo-sdk/models/email.rb', line 42 def error @error end |
#from ⇒ Object
Returns the value of attribute from.
22 23 24 |
# File 'lib/parlo-sdk/models/email.rb', line 22 def from @from end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/parlo-sdk/models/email.rb', line 18 def id @id end |
#last_event_at ⇒ Object
Returns the value of attribute last_event_at.
32 33 34 |
# File 'lib/parlo-sdk/models/email.rb', line 32 def last_event_at @last_event_at end |
#opened ⇒ Object
Returns the value of attribute opened.
28 29 30 |
# File 'lib/parlo-sdk/models/email.rb', line 28 def opened @opened end |
#status ⇒ Object
Returns the value of attribute status.
26 27 28 |
# File 'lib/parlo-sdk/models/email.rb', line 26 def status @status end |
#stream ⇒ Object
Returns the value of attribute stream.
36 37 38 |
# File 'lib/parlo-sdk/models/email.rb', line 36 def stream @stream end |
#subject ⇒ Object
Returns the value of attribute subject.
24 25 26 |
# File 'lib/parlo-sdk/models/email.rb', line 24 def subject @subject end |
#tags ⇒ Object
The tags supplied when the email was sent.
39 40 41 |
# File 'lib/parlo-sdk/models/email.rb', line 39 def @tags end |
#to ⇒ Object
Returns the value of attribute to.
20 21 22 |
# File 'lib/parlo-sdk/models/email.rb', line 20 def to @to end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
85 86 87 |
# File 'lib/parlo-sdk/models/email.rb', line 85 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
90 91 92 |
# File 'lib/parlo-sdk/models/email.rb', line 90 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/parlo-sdk/models/email.rb', line 67 def self.attribute_map { :'id' => :'id', :'to' => :'to', :'from' => :'from', :'subject' => :'subject', :'status' => :'status', :'opened' => :'opened', :'clicked' => :'clicked', :'last_event_at' => :'last_event_at', :'created_at' => :'created_at', :'stream' => :'stream', :'tags' => :'tags', :'error' => :'error' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/parlo-sdk/models/email.rb', line 401 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
120 121 122 123 124 |
# File 'lib/parlo-sdk/models/email.rb', line 120 def self.openapi_all_of [ :'EmailSummary' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 117 |
# File 'lib/parlo-sdk/models/email.rb', line 113 def self.openapi_nullable Set.new([ :'error' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/parlo-sdk/models/email.rb', line 95 def self.openapi_types { :'id' => :'String', :'to' => :'Array<String>', :'from' => :'String', :'subject' => :'String', :'status' => :'String', :'opened' => :'Boolean', :'clicked' => :'Boolean', :'last_event_at' => :'Time', :'created_at' => :'Time', :'stream' => :'String', :'tags' => :'Hash<String, String>', :'error' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/parlo-sdk/models/email.rb', line 369 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && to == o.to && from == o.from && subject == o.subject && status == o.status && opened == o.opened && clicked == o.clicked && last_event_at == o.last_event_at && created_at == o.created_at && stream == o.stream && == o. && error == o.error end |
#eql?(o) ⇒ Boolean
388 389 390 |
# File 'lib/parlo-sdk/models/email.rb', line 388 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
394 395 396 |
# File 'lib/parlo-sdk/models/email.rb', line 394 def hash [id, to, from, subject, status, opened, clicked, last_event_at, created_at, stream, , error].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/parlo-sdk/models/email.rb', line 217 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @to.nil? invalid_properties.push('invalid value for "to", to cannot be nil.') end if @from.nil? invalid_properties.push('invalid value for "from", from cannot be nil.') end if @subject.nil? invalid_properties.push('invalid value for "subject", subject cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @opened.nil? invalid_properties.push('invalid value for "opened", opened cannot be nil.') end if @clicked.nil? invalid_properties.push('invalid value for "clicked", clicked cannot be nil.') end if @stream.nil? invalid_properties.push('invalid value for "stream", stream cannot be nil.') end if @tags.nil? invalid_properties.push('invalid value for "tags", tags cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/parlo-sdk/models/email.rb', line 423 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/parlo-sdk/models/email.rb', line 261 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @to.nil? return false if @from.nil? return false if @subject.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["queued", "sent", "delivered", "bounced", "complained", "failed"]) return false unless status_validator.valid?(@status) return false if @opened.nil? return false if @clicked.nil? return false if @stream.nil? return false if @tags.nil? true end |